@@ -725,6 +725,42 @@ static float CG_DrawAttacker( float y ) {
 	return y + BIGCHAR_HEIGHT + 2;
 }
 
+/*
+================
+CG_DrawSpeedMeter
+
+================
+*/
+static float CG_DrawSpeedMeter( float y ) {
+	char        *s;
+	int         w;
+	vec_t       *vel;
+	int         speed;
+
+	/* speed meter can get in the way of the scoreboard */
+	if ( cg.scoreBoardShowing ) {
+		return y;
+	}
+
+	vel = cg.snap->ps.velocity;
+	/* ignore vertical component of velocity */
+	speed = sqrt(vel[0] * vel[0] + vel[1] * vel[1]);
+
+	s = va( "%i u/s", speed );
+
+	w = CG_DrawStrlen( s ) * BIGCHAR_WIDTH;
+
+	if (cg_drawSpeed.integer == 1) {
+		/* top left-hand corner of screen */
+		CG_DrawBigString( 635 - w, y + 2, s, 1.0F);
+		return y + BIGCHAR_HEIGHT + 4;
+	} else {
+		/* center of screen */
+		CG_DrawBigString( 320 - w / 2, 300, s, 1.0F);
+		return y;
+	}
+}
+
 /*
 ==================
 CG_DrawSnapshot
@@ -1337,6 +1373,9 @@ static void CG_DrawUpperRight( void ) {
 	if ( cg_drawAttacker.integer ) {
 		y = CG_DrawAttacker( y );
 	}
+	if ( cg_drawSpeed.integer ) {
+		y = CG_DrawSpeedMeter( y );
+	}
 
 }
 
