@@ -802,7 +802,9 @@ intptr_t CL_UISystemCalls( intptr_t *args ) {
 
 	case UI_CMD_EXECUTETEXT:
 		if(args[1] == 0
-		&& (!strncmp(VMA(2), "snd_restart", 11) || !strncmp(VMA(2), "vid_restart", 11)))
+		&& (!strncmp(VMA(2), "snd_restart", 11)
+	  	                 || !strncmp(VMA(2), "vid_restart", 11)
+	  	                 || !strncmp(VMA(2), "quit", 5)))
 		{
 			Com_Printf (S_COLOR_YELLOW "turning EXEC_NOW '%.11s' into EXEC_INSERT\n", (const char*)VMA(2));
 			args[1] = EXEC_INSERT;
