@@ -85,7 +85,7 @@ void BotDumpNodeSwitches(bot_state_t *bs) {
 	ClientName(bs->client, netname, sizeof(netname));
 	BotAI_Print(PRT_MESSAGE, "%s at %1.1f switched more than %d AI nodes\n", netname, FloatTime(), MAX_NODESWITCHES);
 	for (i = 0; i < numnodeswitches; i++) {
-		BotAI_Print(PRT_MESSAGE, nodeswitch[i]);
+		BotAI_Print(PRT_MESSAGE, "%s", nodeswitch[i]);
 	}
 	BotAI_Print(PRT_FATAL, "");
 }
@@ -102,7 +102,7 @@ void BotRecordNodeSwitch(bot_state_t *bs, char *node, char *str, char *s) {
 	Com_sprintf(nodeswitch[numnodeswitches], 144, "%s at %2.1f entered %s: %s from %s\n", netname, FloatTime(), node, str, s);
 #ifdef DEBUG
 	if (0) {
-		BotAI_Print(PRT_MESSAGE, nodeswitch[numnodeswitches]);
+		BotAI_Print(PRT_MESSAGE, "%s", nodeswitch[numnodeswitches]);
 	}
 #endif //DEBUG
 	numnodeswitches++;
@@ -525,6 +525,59 @@ int BotGetLongTermGoal(bot_state_t *bs, int tfl, int retreat, bot_goal_t *goal)
 			bs->defendaway_time = 0;
 		}
 	}
+	//For double domination
+	if (bs->ltgtype == LTG_POINTA &&
+				bs->defendaway_time < FloatTime()) {
+		//check for bot typing status message
+		if (bs->teammessage_time && bs->teammessage_time < FloatTime()) {
+			trap_BotGoalName(bs->teamgoal.number, buf, sizeof(buf));
+			BotAI_BotInitialChat(bs, "dd_start_pointa", buf, NULL);
+			trap_BotEnterChat(bs->cs, 0, CHAT_TEAM);
+			//BotVoiceChatOnly(bs, -1, VOICECHAT_ONDEFENSE);
+			bs->teammessage_time = 0;
+		}
+		//set the bot goal
+		memcpy(goal, &ctf_redflag, sizeof(bot_goal_t));
+		//if very close... go away for some time
+		VectorSubtract(goal->origin, bs->origin, dir);
+		if (VectorLengthSquared(dir) < Square(70)) {
+			trap_BotResetAvoidReach(bs->ms);
+			bs->defendaway_time = FloatTime() + 3 + 3 * random();
+			if (BotHasPersistantPowerupAndWeapon(bs)) {
+				bs->defendaway_range = 100;
+			}
+			else {
+				bs->defendaway_range = 350;
+			}
+		}
+		return qtrue;
+	}
+	if (bs->ltgtype == LTG_POINTB &&
+				bs->defendaway_time < FloatTime()) {
+		//check for bot typing status message
+		if (bs->teammessage_time && bs->teammessage_time < FloatTime()) {
+			trap_BotGoalName(bs->teamgoal.number, buf, sizeof(buf));
+			BotAI_BotInitialChat(bs, "dd_start_pointb", buf, NULL);
+			trap_BotEnterChat(bs->cs, 0, CHAT_TEAM);
+			//BotVoiceChatOnly(bs, -1, VOICECHAT_ONDEFENSE);
+			bs->teammessage_time = 0;
+		}
+		//set the bot goal
+		memcpy(goal, &ctf_blueflag, sizeof(bot_goal_t));
+		//if very close... go away for some time
+		VectorSubtract(goal->origin, bs->origin, dir);
+		if (VectorLengthSquared(dir) < Square(70)) {
+			trap_BotResetAvoidReach(bs->ms);
+			bs->defendaway_time = FloatTime() + 3 + 3 * random();
+			if (BotHasPersistantPowerupAndWeapon(bs)) {
+				bs->defendaway_range = 100;
+			}
+			else {
+				bs->defendaway_range = 350;
+			}
+		}
+		return qtrue;
+	}
 	//if defending a key area
 	if (bs->ltgtype == LTG_DEFENDKEYAREA && !retreat &&
 				bs->defendaway_time < FloatTime()) {
@@ -748,7 +801,7 @@ int BotGetLongTermGoal(bot_state_t *bs, int tfl, int retreat, bot_goal_t *goal)
 		return qtrue;
 	}
 #ifdef CTF
-	if (gametype == GT_CTF) {
+	if (gametype == GT_CTF || gametype == GT_CTF_ELIMINATION) {
 		//if going for enemy flag
 		if (bs->ltgtype == LTG_GETFLAG) {
 			//check for bot typing status message
@@ -1872,7 +1925,7 @@ int AINode_Seek_LTG(bot_state_t *bs)
 		else range = 150;
 		//
 #ifdef CTF
-		if (gametype == GT_CTF) {
+		if (gametype == GT_CTF || gametype == GT_CTF_ELIMINATION) {
 			//if carrying a flag the bot shouldn't be distracted too much
 			if (BotCTFCarryingFlag(bs))
 				range = 50;
@@ -2391,7 +2444,7 @@ int AINode_Battle_Retreat(bot_state_t *bs) {
 		bs->check_time = FloatTime() + 1;
 		range = 150;
 #ifdef CTF
-		if (gametype == GT_CTF) {
+		if (gametype == GT_CTF || gametype == GT_CTF_ELIMINATION) {
 			//if carrying a flag the bot shouldn't be distracted too much
 			if (BotCTFCarryingFlag(bs))
 				range = 50;
