@@ -131,7 +131,7 @@ int BotSortTeamMatesByBaseTravelTime(bot_state_t *bs, int *teammates, int maxtea
 	int traveltimes[MAX_CLIENTS];
 	bot_goal_t *goal = NULL;
 
-	if (gametype == GT_CTF || gametype == GT_1FCTF) {
+	if (gametype == GT_CTF || gametype == GT_1FCTF || gametype == GT_CTF_ELIMINATION) {
 		if (BotTeam(bs) == TEAM_RED)
 			goal = &ctf_redflag;
 		else
@@ -178,6 +178,57 @@ int BotSortTeamMatesByBaseTravelTime(bot_state_t *bs, int *teammates, int maxtea
 	return numteammates;
 }
 
+/*
+==================
+BotSortTeamMatesByReletiveTravelTime2ddA
+For Double Domination
+==================
+*/
+int BotSortTeamMatesByRelativeTravelTime2ddA(bot_state_t *bs, int *teammates, int maxteammates) {
+	int i, j, k, numteammates;
+	double traveltime, traveltime2b;
+	char buf[MAX_INFO_STRING];
+	static int maxclients;
+	double traveltimes[MAX_CLIENTS];
+	//int traveltimes2b[MAX_CLIENTS];
+	bot_goal_t *goalA = &ctf_redflag;
+	bot_goal_t *goalB = &ctf_blueflag;
+
+	if (!maxclients)
+		maxclients = trap_Cvar_VariableIntegerValue("sv_maxclients");
+
+	numteammates = 0;
+
+	for (i = 0; i < maxclients && i < MAX_CLIENTS; i++) {
+		trap_GetConfigstring(CS_PLAYERS+i, buf, sizeof(buf));
+		//if no config string or no name
+		if (!strlen(buf) || !strlen(Info_ValueForKey(buf, "n"))) continue;
+		//skip spectators
+		if (atoi(Info_ValueForKey(buf, "t")) == TEAM_SPECTATOR) continue;
+		if (BotSameTeam(bs, i)) {
+			traveltime = (double)BotClientTravelTimeToGoal(i, goalA);
+			traveltime2b = (double)BotClientTravelTimeToGoal(i, goalB);
+			traveltime = traveltime/traveltime2b;
+
+			for (j = 0; j < numteammates; j++) {
+				if (traveltime < traveltimes[j]) {
+					for (k = numteammates; k > j; k--) {
+						traveltimes[k] = traveltimes[k-1];
+						teammates[k] = teammates[k-1];
+					}
+					break;
+				}
+			}
+			traveltimes[j] = traveltime;
+			teammates[j] = i;
+			numteammates++;
+			if (numteammates >= maxteammates) break;
+		}
+	}
+
+	return numteammates;
+}
+
 /*
 ==================
 BotSetTeamMateTaskPreference
@@ -448,9 +499,26 @@ void BotCTFOrders_FlagNotAtBase(bot_state_t *bs) {
 	int numteammates, defenders, attackers, i;
 	int teammates[MAX_CLIENTS];
 	char name[MAX_NETNAME];
+	qboolean weAreAttacking;
 
 	numteammates = BotSortTeamMatesByBaseTravelTime(bs, teammates, sizeof(teammates));
 	BotSortTeamMatesByTaskPreference(bs, teammates, numteammates);
+
+	weAreAttacking = qfalse;
+
+	//In oneway ctf we must all move out of the base (only one strategi, maybe we can also send some to the enemy base  to meet the flag carier?)
+	//We must be defending
+	if(g_elimination_ctf_oneway.integer > 0) {
+		for (i = 0; i < numteammates; i++) {
+			//
+			ClientName(teammates[i], name, sizeof(name));
+			BotAI_BotInitialChat(bs, "cmd_getflag", name, NULL);
+			BotSayTeamOrder(bs, teammates[i]);
+			BotSayVoiceTeamOrder(bs, teammates[i], VOICECHAT_GETFLAG);
+		}
+		return;
+	}
+
 	//passive strategy
 	if (!(bs->ctfstrategy & CTFS_AGRESSIVE)) {
 		//different orders based on the number of team mates
@@ -682,6 +750,54 @@ void BotCTFOrders_EnemyFlagNotAtBase(bot_state_t *bs) {
 	}
 }
 
+/*
+==================
+BotDDorders
+==================
+*/
+
+void BotDDorders_Standard(bot_state_t *bs) {
+	int numteammates, i;
+	int teammates[MAX_CLIENTS];
+	char name[MAX_NETNAME];
+
+	//sort team mates by travel time to base
+	numteammates = BotSortTeamMatesByRelativeTravelTime2ddA(bs, teammates, sizeof(teammates));
+
+	switch(numteammates) {
+		case 1: break;
+		/*case 2: 
+		{
+			//the one closest to point A will take that
+			ClientName(teammates[0], name, sizeof(name));
+			BotAI_BotInitialChat(bs, "cmd_takea", name, NULL);
+			BotSayTeamOrder(bs, teammates[0]);
+			//BotSayVoiceTeamOrder(bs, teammates[0], VOICECHAT_TAKEA);
+			//the other goes for point B
+			ClientName(teammates[1], name, sizeof(name));
+			BotAI_BotInitialChat(bs, "cmd_takeb", name, NULL);
+			BotSayTeamOrder(bs, teammates[1]);
+			//BotSayVoiceTeamOrder(bs, teammates[1], VOICECHAT_TAKEB);
+			break;
+		}*/
+		default:
+		{
+			for(i=0;i<numteammates/2;i++) { //Half take point A
+				ClientName(teammates[i], name, sizeof(name));
+				BotAI_BotInitialChat(bs, "cmd_takea", name, NULL);
+				BotSayTeamOrder(bs, teammates[i]);
+				//BotSayVoiceTeamOrder(bs, teammates[0], VOICECHAT_TAKEA);
+			}
+			for(i=numteammates/2+1;i<numteammates;i++) { //Rest takes point B
+				ClientName(teammates[i], name, sizeof(name));
+				BotAI_BotInitialChat(bs, "cmd_takeb", name, NULL);
+				BotSayTeamOrder(bs, teammates[i]);
+				//BotSayVoiceTeamOrder(bs, teammates[0], VOICECHAT_TAKEB);
+			}
+			break;
+		}
+	}
+}
 
 /*
 ==================
@@ -692,11 +808,40 @@ void BotCTFOrders_BothFlagsAtBase(bot_state_t *bs) {
 	int numteammates, defenders, attackers, i;
 	int teammates[MAX_CLIENTS];
 	char name[MAX_NETNAME];
+	qboolean weAreAttacking;
 
 	//sort team mates by travel time to base
 	numteammates = BotSortTeamMatesByBaseTravelTime(bs, teammates, sizeof(teammates));
 	//sort team mates by CTF preference
 	BotSortTeamMatesByTaskPreference(bs, teammates, numteammates);
+
+	weAreAttacking = qfalse;
+
+	if(g_elimination_ctf_oneway.integer > 0) {
+		//See if we are attacking:
+		if( ( (level.eliminationSides+level.roundNumber)%2 == 0 ) && (BotTeam(bs) == TEAM_RED))
+			weAreAttacking = qtrue;
+		
+		if(weAreAttacking) {
+			for (i = 0; i < numteammates; i++) {
+				//
+				ClientName(teammates[i], name, sizeof(name));
+				BotAI_BotInitialChat(bs, "cmd_getflag", name, NULL);
+				BotSayTeamOrder(bs, teammates[i]);
+				BotSayVoiceTeamOrder(bs, teammates[i], VOICECHAT_GETFLAG);
+			}
+		} else {
+			for (i = 0; i < numteammates; i++) {
+				//
+				ClientName(teammates[i], name, sizeof(name));
+				BotAI_BotInitialChat(bs, "cmd_defendbase", name, NULL);
+				BotSayTeamOrder(bs, teammates[i]);
+				BotSayVoiceTeamOrder(bs, teammates[i], VOICECHAT_DEFEND);
+			}
+		}
+		return; //Sago: Or the leader will make a counter order.
+	}
+
 	//passive strategy
 	if (!(bs->ctfstrategy & CTFS_AGRESSIVE)) {
 		//different orders based on the number of team mates
@@ -844,6 +989,15 @@ void BotCTFOrders(bot_state_t *bs) {
 	}
 }
 
+/*
+==================
+BotDDorders
+==================
+*/
+void BotDDorders(bot_state_t *bs) {
+	BotDDorders_Standard(bs);	
+}
+
 
 /*
 ==================
@@ -1922,6 +2076,8 @@ int FindHumanTeamLeader(bot_state_t *bs) {
 	return qfalse;
 }
 
+int lastRoundNumber; //used to give new orders every round
+
 /*
 ==================
 BotTeamAI
@@ -1932,7 +2088,7 @@ void BotTeamAI(bot_state_t *bs) {
 	char netname[MAX_NETNAME];
 
 	//
-	if ( gametype < GT_TEAM  )
+	if ( gametype < GT_TEAM || g_ffa_gt == 1 )
 		return;
 	// make sure we've got a valid team leader
 	if (!BotValidTeamLeader(bs)) {
@@ -1960,7 +2116,7 @@ void BotTeamAI(bot_state_t *bs) {
 				BotSayVoiceTeamOrder(bs, -1, VOICECHAT_STARTLEADER);
 				ClientName(bs->client, netname, sizeof(netname));
 				strncpy(bs->teamleader, netname, sizeof(bs->teamleader));
-				bs->teamleader[sizeof(bs->teamleader)] = '\0';
+				bs->teamleader[sizeof(bs->teamleader)-1] = '\0';
 				bs->becometeamleader_time = 0;
 			}
 			return;
@@ -1992,14 +2148,16 @@ void BotTeamAI(bot_state_t *bs) {
 			break;
 		}
 		case GT_CTF:
+		case GT_CTF_ELIMINATION:
 		{
 			//if the number of team mates changed or the flag status changed
 			//or someone wants to know what to do
-			if (bs->numteammates != numteammates || bs->flagstatuschanged || bs->forceorders) {
+			if (bs->numteammates != numteammates || bs->flagstatuschanged || bs->forceorders || lastRoundNumber != level.roundNumber) {
 				bs->teamgiveorders_time = FloatTime();
 				bs->numteammates = numteammates;
 				bs->flagstatuschanged = qfalse;
 				bs->forceorders = qfalse;
+				lastRoundNumber = level.roundNumber;
 			}
 			//if there were no flag captures the last 3 minutes
 			if (bs->lastflagcapture_time < FloatTime() - 240) {
@@ -2018,6 +2176,24 @@ void BotTeamAI(bot_state_t *bs) {
 			}
 			break;
 		}
+		case GT_DOUBLE_D:
+		{
+			//if the number of team mates changed or the domination point status changed
+			//or someone wants to know what to do
+			if (bs->numteammates != numteammates || bs->flagstatuschanged || bs->forceorders) {
+				bs->teamgiveorders_time = FloatTime();
+				bs->numteammates = numteammates;
+				bs->flagstatuschanged = qfalse;
+				bs->forceorders = qfalse;
+			}
+			//if it's time to give orders
+			if (bs->teamgiveorders_time && bs->teamgiveorders_time < FloatTime() - 3) {
+				BotDDorders(bs);
+				//
+				bs->teamgiveorders_time = 0;
+			}
+			break;
+		}
 #ifdef MISSIONPACK
 		case GT_1FCTF:
 		{
