@@ -48,7 +48,6 @@ float	pm_spectatorfriction = 5.0f;
 
 int		c_pmove = 0;
 
-
 /*
 ===============
 PM_AddEvent
@@ -234,11 +233,14 @@ static void PM_Friction( void ) {
 ==============
 PM_Accelerate
 
+TODO: bunny hoping
+
 Handles user intended acceleration
 ==============
 */
 static void PM_Accelerate( vec3_t wishdir, float wishspeed, float accel ) {
 #if 1
+
 	// q2 style
 	int			i;
 	float		addspeed, accelspeed, currentspeed;
@@ -273,6 +275,7 @@ static void PM_Accelerate( vec3_t wishdir, float wishspeed, float accel ) {
 	}
 
 	VectorMA( pm->ps->velocity, canPush, pushDir, pm->ps->velocity );
+}
 #endif
 }
 
@@ -357,6 +360,8 @@ PM_CheckJump
 =============
 */
 static qboolean PM_CheckJump( void ) {
+
+
 	if ( pm->ps->pm_flags & PMF_RESPAWNED ) {
 		return qfalse;		// don't allow jump until all buttons are up
 	}
@@ -366,6 +371,7 @@ static qboolean PM_CheckJump( void ) {
 		return qfalse;
 	}
 
+
 	// must wait for jump to be released
 	if ( pm->ps->pm_flags & PMF_JUMP_HELD ) {
 		// clear upmove so cmdscale doesn't lower running speed
@@ -373,6 +379,9 @@ static qboolean PM_CheckJump( void ) {
 		return qfalse;
 	}
 
+	
+
+
 	pml.groundPlane = qfalse;		// jumping away
 	pml.walking = qfalse;
 	pm->ps->pm_flags |= PMF_JUMP_HELD;
@@ -1533,6 +1542,9 @@ static void PM_TorsoAnimation( void ) {
 PM_Weapon
 
 Generates weapon events and modifes the weapon counter
+
+Elimination TODO:
+Make this thing stop during warmup (done)
 ==============
 */
 static void PM_Weapon( void ) {
@@ -1544,7 +1556,7 @@ static void PM_Weapon( void ) {
 	}
 
 	// ignore if spectator
-	if ( pm->ps->persistant[PERS_TEAM] == TEAM_SPECTATOR ) {
+	if ( pm->ps->persistant[PERS_TEAM] == TEAM_SPECTATOR || pm->ps->pm_type == PM_SPECTATOR) {
 		return;
 	}
 
@@ -1635,8 +1647,8 @@ static void PM_Weapon( void ) {
 		return;
 	}
 
-	// take an ammo away if not infinite
-	if ( pm->ps->ammo[ pm->ps->weapon ] != -1 ) {
+	// take an ammo away if not infinite, 999 or up
+	if ( !(pm->ps->ammo[ pm->ps->weapon ] == -1 || pm->ps->ammo[ pm->ps->weapon ] >=999 )) {
 		pm->ps->ammo[ pm->ps->weapon ]--;
 	}
 
@@ -2000,6 +2012,7 @@ void PmoveSingle (pmove_t *pmove) {
 	PM_SetWaterLevel();
 
 	// weapons
+	if(!(pm->ps->pm_flags & PMF_ELIMWARMUP))
 	PM_Weapon();
 
 	// torso animation
