@@ -1339,6 +1339,159 @@ static const char *gameNames[] = {
 	"Domination"
 };
 
+/*
+==================
+allowedVote
+==================
+ */
+#define MAX_VOTENAME_LENGTH 14 //currently the longest string is "/map_restart/\0" (14 chars)
+int allowedVote(char *commandStr) {
+    char tempStr[MAX_VOTENAME_LENGTH]; 
+    int length;
+    char voteNames[MAX_CVAR_VALUE_STRING];
+    trap_Cvar_VariableStringBuffer( "g_voteNames", voteNames, sizeof( voteNames ) );
+    if(!Q_stricmp(voteNames, "*" ))
+        return qtrue; //if star, everything is allowed
+    length = strlen(commandStr);
+    if(length>MAX_VOTENAME_LENGTH-3)
+    {
+        //Error: too long
+        return qfalse;
+    }
+    tempStr[0] = '/';
+    strncpy(&tempStr[1],commandStr,length);
+    tempStr[length+1] = '/';
+    tempStr[length+2] = '\0';
+    if(Q_stristr(voteNames,tempStr) != NULL)
+        return qtrue;
+    else
+        return qfalse;
+}
+
+/*
+==================
+allowedMap
+==================
+ */
+#define MAX_MAPNAME_LENGTH 34
+int allowedMap(char *mapname) {
+    char tempStr[MAX_MAPNAME_LENGTH]; 
+    int length;
+    char voteMaps[MAX_CVAR_VALUE_STRING]; //= g_voteMaps.string;
+    trap_Cvar_VariableStringBuffer( "g_voteMaps", voteMaps, sizeof( voteMaps ) );
+    
+    if(!Q_stricmp(voteMaps, "*" ))
+        return qtrue; //if star, everything is allowed
+    length = strlen(mapname);
+    if(length>MAX_MAPNAME_LENGTH-3)
+    {
+        //Error: too long
+        return qfalse;
+    }
+    tempStr[0] = '/';
+    strncpy(&tempStr[1],mapname,length);
+    tempStr[length+1] = '/';
+    tempStr[length+2] = '\0';
+    
+    if(Q_stristr(voteMaps,tempStr) != NULL) {
+        return qtrue;
+    }
+    trap_Cvar_VariableStringBuffer( "g_voteMaps1", voteMaps, sizeof( voteMaps ) );
+    if(Q_stristr(voteMaps,tempStr) != NULL) {
+        return qtrue;
+    }
+    trap_Cvar_VariableStringBuffer( "g_voteMaps2", voteMaps, sizeof( voteMaps ) );
+    if(Q_stristr(voteMaps,tempStr) != NULL) {
+        return qtrue;
+    }
+    trap_Cvar_VariableStringBuffer( "g_voteMaps3", voteMaps, sizeof( voteMaps ) );
+    if(Q_stristr(voteMaps,tempStr) != NULL) {
+        return qtrue;
+    }
+    trap_Cvar_VariableStringBuffer( "g_voteMaps4", voteMaps, sizeof( voteMaps ) );
+    if(Q_stristr(voteMaps,tempStr) != NULL) {
+        return qtrue;
+    }
+    trap_Cvar_VariableStringBuffer( "g_voteMaps", voteMaps, sizeof( voteMaps ) );
+    G_Printf("Maps on server: %s ",voteMaps);
+    trap_Cvar_VariableStringBuffer( "g_voteMaps1", voteMaps, sizeof( voteMaps ) );
+    G_Printf("%s ",voteMaps);
+    trap_Cvar_VariableStringBuffer( "g_voteMaps2", voteMaps, sizeof( voteMaps ) );
+    G_Printf("%s ",voteMaps);
+    trap_Cvar_VariableStringBuffer( "g_voteMaps3", voteMaps, sizeof( voteMaps ) );
+    G_Printf("%s ",voteMaps);
+    trap_Cvar_VariableStringBuffer( "g_voteMaps4", voteMaps, sizeof( voteMaps ) );
+    G_Printf("%s\n",voteMaps);
+    //The map was not found
+    return qfalse;
+}
+
+/*
+==================
+allowedGametype
+==================
+ */
+#define MAX_GAMETYPENAME_LENGTH 5 //currently the longest string is "/12/\0" (5 chars)
+int allowedGametype(char *gametypeStr) {
+    char tempStr[MAX_GAMETYPENAME_LENGTH]; 
+    int length;
+    char voteGametypes[MAX_CVAR_VALUE_STRING];
+    trap_Cvar_VariableStringBuffer( "g_voteGametypes", voteGametypes, sizeof( voteGametypes ) );
+    if(!Q_stricmp(voteGametypes, "*" ))
+        return qtrue; //if star, everything is allowed
+    length = strlen(gametypeStr);
+    if(length>MAX_GAMETYPENAME_LENGTH-3)
+    {
+        //Error: too long
+        return qfalse;
+    }
+    tempStr[0] = '/';
+    strncpy(&tempStr[1],gametypeStr,length);
+    tempStr[length+1] = '/';
+    tempStr[length+2] = '\0';
+    if(Q_stristr(voteGametypes,tempStr) != NULL)
+        return qtrue;
+    else {
+        return qfalse;
+    }
+}
+
+/*
+==================
+allowedTimelimit
+==================
+ */
+int allowedTimelimit(int limit) {
+    int min, max;
+    min = g_voteMinTimelimit.integer;
+    max = g_voteMaxTimelimit.integer;
+    if(limit<min && limit != 0)
+        return qfalse;
+    if(max!=0 && limit>max)
+        return qfalse;
+    if(limit==0 && max > 0)
+        return qfalse;
+    return qtrue;
+}
+
+/*
+==================
+allowedFraglimit
+==================
+ */
+int allowedFraglimit(int limit) {
+    int min, max;
+    min = g_voteMinFraglimit.integer;
+    max = g_voteMaxFraglimit.integer;
+    if(limit<min && limit != 0)
+        return qfalse;
+    if(max != 0 && limit>max)
+        return qfalse;
+    if(limit==0 && max > 0)
+        return qfalse;
+    return qtrue;
+}
+
 /*
 ==================
 Cmd_CallVote_f
@@ -1375,6 +1528,8 @@ void Cmd_CallVote_f( gentity_t *ent ) {
 		trap_SendServerCommand( ent-g_entities, "print \"Invalid vote string.\n\"" );
 		return;
 	}
+        
+        
 
 	if ( !Q_stricmp( arg1, "map_restart" ) ) {
 	} else if ( !Q_stricmp( arg1, "nextmap" ) ) {
@@ -1390,6 +1545,11 @@ void Cmd_CallVote_f( gentity_t *ent ) {
 		trap_SendServerCommand( ent-g_entities, "print \"Vote commands are: map_restart, nextmap, map <mapname>, g_gametype <n>, kick <player>, clientkick <clientnum>, g_doWarmup, timelimit <time>, fraglimit <frags>.\n\"" );
 		return;
 	}
+        
+        if(!allowedVote(arg1)) {
+                trap_SendServerCommand( ent-g_entities, "print \"Not allowed here.\n\"" );
+		return;
+        }
 
 	// if there is still a vote to be executed
 	if ( level.voteExecuteTime ) {
@@ -1404,6 +1564,11 @@ void Cmd_CallVote_f( gentity_t *ent ) {
 			trap_SendServerCommand( ent-g_entities, "print \"Invalid gametype.\n\"" );
 			return;
 		}
+                
+                if(!allowedGametype(arg2)){
+                    trap_SendServerCommand( ent-g_entities, "print \"Gametype is not available.\n\"" );
+                    return;
+                }
 
 		Com_sprintf( level.voteString, sizeof( level.voteString ), "%s %d", arg1, i );
 		Com_sprintf( level.voteDisplayString, sizeof( level.voteDisplayString ), "%s %s", arg1, gameNames[i] );
@@ -1411,6 +1576,11 @@ void Cmd_CallVote_f( gentity_t *ent ) {
 		// special case for map changes, we want to reset the nextmap setting
 		// this allows a player to change maps, but not upset the map rotation
 		char	s[MAX_STRING_CHARS];
+                
+                if(!allowedMap(arg2)){
+                    trap_SendServerCommand( ent-g_entities, "print \"Map is not available.\n\"" );
+                    return;
+                }
 
 		trap_Cvar_VariableStringBuffer( "nextmap", s, sizeof(s) );
 		if (*s) {
@@ -1421,6 +1591,11 @@ void Cmd_CallVote_f( gentity_t *ent ) {
 		Com_sprintf( level.voteDisplayString, sizeof( level.voteDisplayString ), "%s", level.voteString );
 	} else if ( !Q_stricmp( arg1, "nextmap" ) ) {
 		char	s[MAX_STRING_CHARS];
+                
+                if(!allowedMap(arg2)){
+                    trap_SendServerCommand( ent-g_entities, "print \"Map is not available.\n\"" );
+                    return;
+                }
 
 		trap_Cvar_VariableStringBuffer( "nextmap", s, sizeof(s) );
 		if (!*s) {
@@ -1429,6 +1604,24 @@ void Cmd_CallVote_f( gentity_t *ent ) {
 		}
 		Com_sprintf( level.voteString, sizeof( level.voteString ), "vstr nextmap");
 		Com_sprintf( level.voteDisplayString, sizeof( level.voteDisplayString ), "%s", level.voteString );
+        } else if ( !Q_stricmp( arg1, "fraglimit" ) ) {
+                i = atoi(arg2);
+                if(!allowedFraglimit(i)) {
+                    trap_SendServerCommand( ent-g_entities, "print \"Cannot set fraglimit.\n\"" );
+                    return;
+                }
+            
+                Com_sprintf( level.voteString, sizeof( level.voteString ), "%s \"%s\"", arg1, arg2 );
+		Com_sprintf( level.voteDisplayString, sizeof( level.voteDisplayString ), "%s", level.voteString );
+        } else if ( !Q_stricmp( arg1, "timelimit" ) ) {
+                i = atoi(arg2);
+                if(!allowedTimelimit(i)) {
+                    trap_SendServerCommand( ent-g_entities, "print \"Cannot set timelimit.\n\"" );
+                    return;
+                }
+            
+                Com_sprintf( level.voteString, sizeof( level.voteString ), "%s \"%s\"", arg1, arg2 );
+		Com_sprintf( level.voteDisplayString, sizeof( level.voteDisplayString ), "%s", level.voteString );
 	} else {
 		Com_sprintf( level.voteString, sizeof( level.voteString ), "%s \"%s\"", arg1, arg2 );
 		Com_sprintf( level.voteDisplayString, sizeof( level.voteDisplayString ), "%s", level.voteString );
