@@ -138,9 +138,19 @@ vmCvar_t	g_elimination_ctf_oneway;
 //beta 18 (oa 0.7.6)
 vmCvar_t        g_awardpushing; //The server can decide if players are awarded for pushing people in lave etc.
 
+//new in beta 19
+vmCvar_t        g_voteNames;
+vmCvar_t        g_voteMaps;
+vmCvar_t        g_voteGametypes;
+vmCvar_t        g_voteStrictGametypes;
+vmCvar_t        g_voteMinTimelimit;
+vmCvar_t        g_voteMaxTimelimit;
+vmCvar_t        g_voteMinFraglimit;
+vmCvar_t        g_voteMaxFraglimit;
+//new in beta 19 end
+
 //unlagged - server options
 vmCvar_t	g_delagHitscan;
-vmCvar_t	g_unlaggedVersion;
 vmCvar_t	g_truePing;
 vmCvar_t	g_lightningDamage;
 vmCvar_t	sv_fps;
@@ -208,6 +218,18 @@ static cvarTable_t		gameCvarTable[] = {
 	{ &g_podiumDrop, "g_podiumDrop", "70", 0, 0, qfalse },
 
 	{ &g_allowVote, "g_allowVote", "1", CVAR_ARCHIVE, 0, qfalse },
+        
+        //new in beta 19
+        { &g_voteNames, "g_voteNames", "/map_restart/nextmap/map/g_gametype/kick/clientkick/g_doWarmup/timelimit/fraglimit/", CVAR_ARCHIVE, 0, qfalse }, //clientkick g_doWarmup timelimit fraglimit
+        { &g_voteMaps, "g_voteMaps", "*", CVAR_ARCHIVE, 0, qfalse },
+        { &g_voteGametypes, "g_voteGametypes", "/0/1/3/4/8/9/10/11/", CVAR_ARCHIVE, 0, qfalse },
+        { &g_voteStrictGametypes, "g_voteStrictGametypes", "0", CVAR_ARCHIVE, 0, qfalse },
+        { &g_voteMaxTimelimit, "g_voteMaxTimelimit", "0", CVAR_ARCHIVE, 0, qfalse },
+        { &g_voteMinTimelimit, "g_voteMinTimelimit", "0", CVAR_ARCHIVE, 0, qfalse },
+        { &g_voteMaxFraglimit, "g_voteMaxFraglimit", "0", CVAR_ARCHIVE, 0, qfalse },
+        { &g_voteMinFraglimit, "g_voteMinFraglimit", "0", CVAR_ARCHIVE, 0, qfalse },
+        //new in beta 19 end
+        
 	{ &g_listEntity, "g_listEntity", "0", 0, 0, qfalse },
 
 #ifdef MISSIONPACK
@@ -231,7 +253,6 @@ static cvarTable_t		gameCvarTable[] = {
 
 //unlagged - server options
 	{ &g_delagHitscan, "g_delagHitscan", "0", CVAR_ARCHIVE | CVAR_SERVERINFO, 0, qtrue },
-	{ &g_unlaggedVersion, "g_unlaggedVersion", "2.0", CVAR_ROM | CVAR_SERVERINFO, 0, qfalse },
 	{ &g_truePing, "g_truePing", "0", CVAR_ARCHIVE, 0, qtrue },
 	{ &g_lightningDamage, "g_lightningDamage", "8", 0, 0, qtrue },
 	// it's CVAR_SYSTEMINFO so the client's sv_fps will be automagically set to its value
@@ -520,6 +541,14 @@ void G_InitGame( int levelTime, int randomSeed, int restart ) {
 	srand( randomSeed );
 
 	G_RegisterCvars();
+        
+        //disable unwanted cvars
+        if( g_gametype.integer == GT_SINGLE_PLAYER )
+        {
+            g_instantgib.integer = 0;
+            g_rockets.integer = 0;
+            g_vampire.value = 0.0f;
+        }
 
 	G_ProcessIPBans();
 
@@ -1284,7 +1313,7 @@ void QDECL G_LogPrintf( const char *fmt, ... ) {
 	Com_sprintf( string, sizeof(string), "%3i:%i%i ", min, tens, sec );
 
 	va_start( argptr, fmt );
-	Q_vsnprintf(string + 7, sizeof(string - 7), fmt, argptr);
+	Q_vsnprintf(string + 7, sizeof(string) - 7, fmt, argptr);
 	va_end( argptr );
 
 	if ( g_dedicated.integer ) {
@@ -1968,6 +1997,7 @@ CheckDomination
 */
 void CheckDomination(void) {
 	int i;
+        int scoreFactor = 1;
 
 	if ( (level.numPlayingClients < 1) || (g_gametype.integer != GT_DOMINATION) ) {
 		return;
@@ -1982,7 +2012,9 @@ void CheckDomination(void) {
 		return;
 
 	//Sago: I use if instead of while, since if the server stops for more than 2 seconds people should not be allowed to score anyway
-	if(level.time>=level.dom_scoreGiven*DOM_SECSPERPOINT) {
+	if(level.domination_points_count>3)
+            scoreFactor = 2; //score more slowly if there are many points
+        if(level.time>=level.dom_scoreGiven*DOM_SECSPERPOINT*scoreFactor) {
 		for(i=0;i<level.domination_points_count;i++) {
 			if ( level.pointStatusDom[i] == TEAM_RED )
 				AddTeamScore(level.intermission_origin,TEAM_RED,1);
@@ -1990,10 +2022,9 @@ void CheckDomination(void) {
 				AddTeamScore(level.intermission_origin,TEAM_BLUE,1);
 		}
 		level.dom_scoreGiven++;
-		while(level.time>level.dom_scoreGiven*DOM_SECSPERPOINT)
+		while(level.time>level.dom_scoreGiven*DOM_SECSPERPOINT*scoreFactor)
 			level.dom_scoreGiven++;
 		CalculateRanks();
-		
 	}
 }
 
