@@ -233,6 +233,12 @@ void Bullet_Fire (gentity_t *ent, float spread, int damage ) {
 //unlagged - backward reconciliation #2
 
 		trap_Trace (&tr, muzzle, NULL, NULL, end, passent, MASK_SHOT);
+                
+//unlagged - backward reconciliation #2
+		// put them back
+		G_UndoTimeShiftFor( ent );
+//unlagged - backward reconciliation #2
+                
 		if ( tr.surfaceFlags & SURF_NOIMPACT ) {
 			return;
 		}
