@@ -32,16 +32,16 @@ MULTIPLAYER MENU (SERVER BROWSER)
 #include "ui_local.h"
 
 
-#define MAX_GLOBALSERVERS		124
+#define MAX_GLOBALSERVERS		256
 #define MAX_PINGREQUESTS		32
 #define MAX_ADDRESSLENGTH		64
-#define MAX_HOSTNAMELENGTH		22
-#define MAX_MAPNAMELENGTH		16
-#define MAX_LISTBOXITEMS		124
+#define MAX_HOSTNAMELENGTH		31
+#define MAX_MAPNAMELENGTH		20
+#define MAX_LISTBOXITEMS		256
 #define MAX_LOCALSERVERS		124
 #define MAX_STATUSLENGTH		64
 #define MAX_LEAGUELENGTH		28
-#define MAX_LISTBOXWIDTH		62
+#define MAX_LISTBOXWIDTH		70
 
 #define ART_BACK0				"menu/art/back_0"
 #define ART_BACK1				"menu/art/back_1"
@@ -187,7 +187,7 @@ typedef struct servernode_s {
 	int		maxclients;
 	int		pingtime;
 	int		gametype;
-	char	gamename[12];
+	char	gamename[16];
 	int		nettype;
 	int		minPing;
 	int		maxPing;
@@ -196,7 +196,7 @@ typedef struct servernode_s {
 } servernode_t; 
 
 typedef struct {
-	char			buff[MAX_LISTBOXWIDTH];
+	char			buff[MAX_LISTBOXWIDTH+22]; //	+20 gives room for color codes... Sago: I need two more
 	servernode_t*	servernode;
 } table_t;
 
@@ -379,6 +379,57 @@ static void ArenaServers_UpdatePicture( void ) {
 	g_arenaservers.mappic.shader = 0;
 }
 
+/*
+=================
+	Q_strcpyColor - This function will return the real length of the string if numChars
+		len of character data is desired. It looks for color codes and adds 2 to the length
+		for each combo found. This is used to make color strings show up correctly in column
+		formatted environments. Otherwise, the columns will be off 2 * num of color codes.
+=================
+*/
+int Q_strcpyColor( const char *src, char *dest, int numChars )
+{
+int count, len;
+char *d;
+const char *s;
+
+	if( !src || !dest )
+	{
+		return 0;
+	}
+
+	count = len = 0;
+	s = src;
+	d = dest;
+
+	while( *s && count < numChars )
+	{
+		if( Q_IsColorString( s ))
+		{
+			*d++ = *s++;
+			*d++ = *s++;
+			len += 2;
+			continue;
+		}
+		*d = *s;
+		s++;
+		d++;
+		count++;
+		len++;
+	}
+
+	// Now fill up the end of the string with space characters if needed...
+	while( count < numChars )
+	{
+		*d = ' ';
+                //d[len] = ' ';
+		d++;
+		len++;
+		count++;
+	}
+	return len;
+}
+
 
 /*
 =================
@@ -388,11 +439,11 @@ ArenaServers_UpdateMenu
 static void ArenaServers_UpdateMenu( void ) {
 	int				i;
 	int				j;
-	int				count;
+	int				count, bufAddr;
 	char*			buff;
 	servernode_t*	servernodeptr;
 	table_t*		tableptr;
-	char			*pingColor;
+	char			*b, *pingColor;
 
 	if( g_arenaservers.numqueriedservers > 0 ) {
 		// servers found
@@ -565,17 +616,39 @@ static void ArenaServers_UpdateMenu( void ) {
 			pingColor = S_COLOR_RED;
 		}
 
-		Com_sprintf( buff, MAX_LISTBOXWIDTH, "%-20.20s %-12.12s %2d/%2d %-8.8s %3s %s%3d " S_COLOR_YELLOW "%s", 
+                /*
+		Com_sprintf( buff, MAX_LISTBOXWIDTH, "%-20.20s %-12.12s %2d/%2d %-8.8s %3s %s%3d ", 
 			servernodeptr->hostname, servernodeptr->mapname, servernodeptr->numclients,
  			servernodeptr->maxclients, servernodeptr->gamename,
-			netnames[servernodeptr->nettype], pingColor, servernodeptr->pingtime, servernodeptr->bPB ? "Yes" : "No" );
+			netnames[servernodeptr->nettype], pingColor, servernodeptr->pingtime ); //, servernodeptr->bPB ? "Yes" : "No"
+                 */
+                b = buff;
+		bufAddr = Q_strcpyColor( servernodeptr->hostname, b, 30 );
+		b += bufAddr; 
+		*b++ = ' ';
+                //*b++ = '^';
+                //*b++ = '7';
+	
+		bufAddr = Q_strcpyColor( servernodeptr->mapname, b, 16 );
+		b += bufAddr;
+		*b++ = ' ';
+	
+		Com_sprintf( b, 7, "%2d/%2d ", servernodeptr->numclients, 
+														servernodeptr->maxclients );
+		b += 6;
+	
+		bufAddr = Q_strcpyColor( servernodeptr->gamename, b, 12 );
+		b += bufAddr;
+		*b++ = ' ';
+	
+		Com_sprintf( b, 12, "%s%3d ", 	pingColor, servernodeptr->pingtime );
 		j++;
 	}
 
 	g_arenaservers.list.numitems = j;
 	g_arenaservers.list.curvalue = 0;
 	g_arenaservers.list.top      = 0;
-
+        
 	// update picture
 	ArenaServers_UpdatePicture();
 }
@@ -1463,7 +1536,7 @@ static void ArenaServers_MenuInit( void ) {
 	g_arenaservers.list.generic.flags			= QMF_HIGHLIGHT_IF_FOCUS;
 	g_arenaservers.list.generic.id				= ID_LIST;
 	g_arenaservers.list.generic.callback		= ArenaServers_Event;
-	g_arenaservers.list.generic.x				= 72;
+	g_arenaservers.list.generic.x				= 22;
 	g_arenaservers.list.generic.y				= y;
 	g_arenaservers.list.width					= MAX_LISTBOXWIDTH;
 	g_arenaservers.list.height					= 11;
@@ -1484,8 +1557,8 @@ static void ArenaServers_MenuInit( void ) {
 	g_arenaservers.arrows.generic.name			= ART_ARROWS0;
 	g_arenaservers.arrows.generic.flags			= QMF_LEFT_JUSTIFY|QMF_INACTIVE;
 	g_arenaservers.arrows.generic.callback		= ArenaServers_Event;
-	g_arenaservers.arrows.generic.x				= 512+48;
-	g_arenaservers.arrows.generic.y				= 240-64+16;
+	g_arenaservers.arrows.generic.x				= 512+48+12;
+	g_arenaservers.arrows.generic.y				= 240-64+48;
 	g_arenaservers.arrows.width					= 64;
 	g_arenaservers.arrows.height				= 128;
 
@@ -1493,8 +1566,8 @@ static void ArenaServers_MenuInit( void ) {
 	g_arenaservers.up.generic.flags				= QMF_LEFT_JUSTIFY|QMF_PULSEIFFOCUS|QMF_MOUSEONLY;
 	g_arenaservers.up.generic.callback			= ArenaServers_Event;
 	g_arenaservers.up.generic.id				= ID_SCROLL_UP;
-	g_arenaservers.up.generic.x					= 512+48;
-	g_arenaservers.up.generic.y					= 240-64+16;
+	g_arenaservers.up.generic.x					= 512+48+12;
+	g_arenaservers.up.generic.y					= 240-64+48;
 	g_arenaservers.up.width						= 64;
 	g_arenaservers.up.height					= 64;
 	g_arenaservers.up.focuspic					= ART_ARROWS_UP;
@@ -1503,8 +1576,8 @@ static void ArenaServers_MenuInit( void ) {
 	g_arenaservers.down.generic.flags			= QMF_LEFT_JUSTIFY|QMF_PULSEIFFOCUS|QMF_MOUSEONLY;
 	g_arenaservers.down.generic.callback		= ArenaServers_Event;
 	g_arenaservers.down.generic.id				= ID_SCROLL_DOWN;
-	g_arenaservers.down.generic.x				= 512+48;
-	g_arenaservers.down.generic.y				= 240+16;
+	g_arenaservers.down.generic.x				= 512+48+12;
+	g_arenaservers.down.generic.y				= 240+48;
 	g_arenaservers.down.width					= 64;
 	g_arenaservers.down.height					= 64;
 	g_arenaservers.down.focuspic				= ART_ARROWS_DOWN;
