@@ -53,7 +53,7 @@ START SERVER MENU *****
 
 #define	MAX_SERVERSTEXT	8192
 
-#define MAX_SERVERMAPS	64
+#define MAX_SERVERMAPS	MAX_ARENAS
 #define MAX_NAMELENGTH	16
 
 #define ID_GAMETYPE				10
