@@ -266,11 +266,14 @@ typedef struct {
 	menuslider_s	tq;
 	menulist_s  	fs;
 	menulist_s  	lighting;
+        menulist_s  	flares;
+        menulist_s  	bloom;
 	menulist_s  	allow_extensions;
 	menulist_s  	texturebits;
 	menulist_s  	colordepth;
 	menulist_s  	geometry;
 	menulist_s  	filter;
+        menulist_s  	aniso;
 	menutext_s		driverinfo;
 
 	menubitmap_s	apply;
@@ -283,10 +286,13 @@ typedef struct
 	qboolean fullscreen;
 	int tq;
 	int lighting;
+        qboolean flares;
+        qboolean bloom;
 	int colordepth;
 	int texturebits;
 	int geometry;
 	int filter;
+        int aniso;
 	int driver;
 	qboolean extensions;
 } InitialVideoOptions_s;
@@ -297,22 +303,22 @@ static graphicsoptions_t		s_graphicsoptions;
 static InitialVideoOptions_s s_ivo_templates[] =
 {
 	{
-		6, qtrue, 3, 0, 2, 2, 2, 1, 0, qtrue
+		6, qtrue, 3, 0, qfalse,qfalse, 2, 2, 2, 1, 0, 0, qtrue
 	},
 	{
-		4, qtrue, 2, 0, 2, 2, 1, 1, 0, qtrue	// JDC: this was tq 3
+		4, qtrue, 2, 0, qfalse,qfalse, 2, 2, 1, 1, 0, 0, qtrue	// JDC: this was tq 3
 	},
 	{
-		3, qtrue, 2, 0, 0, 0, 1, 0, 0, qtrue
+		3, qtrue, 2, 0, qfalse,qfalse, 0, 0, 1, 0, 0, 0, qtrue
 	},
 	{
-		2, qtrue, 1, 0, 1, 0, 0, 0, 0, qtrue
+		2, qtrue, 1, 0, qfalse,qfalse, 1, 0, 0, 0, 0, 0, qtrue
 	},
 	{
-		2, qtrue, 1, 1, 1, 0, 0, 0, 0, qtrue
+		2, qtrue, 1, 1, qfalse,qfalse, 1, 0, 0, 0, 0, 0, qtrue
 	},
 	{
-		3, qtrue, 1, 0, 0, 0, 1, 0, 0, qtrue
+		3, qtrue, 1, 0, qfalse,qfalse, 0, 0, 1, 0, 0, 0, qtrue
 	}
 };
 
@@ -403,8 +409,11 @@ static void GraphicsOptions_GetInitialVideo( void )
 	s_ivo.extensions  = s_graphicsoptions.allow_extensions.curvalue;
 	s_ivo.tq          = s_graphicsoptions.tq.curvalue;
 	s_ivo.lighting    = s_graphicsoptions.lighting.curvalue;
+        s_ivo.flares      = s_graphicsoptions.flares.curvalue;
+        s_ivo.bloom      = s_graphicsoptions.bloom.curvalue;
 	s_ivo.geometry    = s_graphicsoptions.geometry.curvalue;
 	s_ivo.filter      = s_graphicsoptions.filter.curvalue;
+        s_ivo.aniso      = s_graphicsoptions.aniso.curvalue;
 	s_ivo.texturebits = s_graphicsoptions.texturebits.curvalue;
 }
 
@@ -431,10 +440,16 @@ static void GraphicsOptions_CheckConfig( void )
 			continue;
 		if ( s_ivo_templates[i].lighting != s_graphicsoptions.lighting.curvalue )
 			continue;
+                if ( s_ivo_templates[i].flares != s_graphicsoptions.flares.curvalue )
+			continue;
+                if ( s_ivo_templates[i].bloom != s_graphicsoptions.bloom.curvalue )
+			continue;
 		if ( s_ivo_templates[i].geometry != s_graphicsoptions.geometry.curvalue )
 			continue;
 		if ( s_ivo_templates[i].filter != s_graphicsoptions.filter.curvalue )
 			continue;
+                if ( s_ivo_templates[i].aniso != s_graphicsoptions.aniso.curvalue )
+			continue;
 //		if ( s_ivo_templates[i].texturebits != s_graphicsoptions.texturebits.curvalue )
 //			continue;
 		s_graphicsoptions.list.curvalue = i;
@@ -503,6 +518,14 @@ static void GraphicsOptions_UpdateMenuItems( void )
 	{
 		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
 	}
+        if ( s_ivo.flares != s_graphicsoptions.flares.curvalue )
+	{
+		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
+	}
+        if ( s_ivo.bloom != s_graphicsoptions.bloom.curvalue )
+	{
+		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
+	}
 	if ( s_ivo.colordepth != s_graphicsoptions.colordepth.curvalue )
 	{
 		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
@@ -523,6 +546,10 @@ static void GraphicsOptions_UpdateMenuItems( void )
 	{
 		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
 	}
+        if ( s_ivo.aniso != s_graphicsoptions.aniso.curvalue )
+	{
+		s_graphicsoptions.apply.generic.flags &= ~(QMF_HIDDEN|QMF_INACTIVE);
+	}
 
 	GraphicsOptions_CheckConfig();
 }	
@@ -577,7 +604,20 @@ static void GraphicsOptions_ApplyChanges( void *unused, int notification )
 	trap_Cvar_SetValue( "r_depthbits", 0 );
 	trap_Cvar_SetValue( "r_stencilbits", 0 );
 	trap_Cvar_SetValue( "r_vertexLight", s_graphicsoptions.lighting.curvalue );
-
+        trap_Cvar_SetValue( "r_flares", s_graphicsoptions.flares.curvalue );
+        trap_Cvar_SetValue( "r_bloom", s_graphicsoptions.bloom.curvalue );
+        
+        //r_ext_texture_filter_anisotropic is special
+        if(s_graphicsoptions.aniso.curvalue) {
+            trap_Cvar_SetValue( "r_ext_max_anisotropy", s_graphicsoptions.aniso.curvalue*2 );
+            trap_Cvar_SetValue( "r_ext_texture_filter_anisotropic", qtrue );
+        }
+        else
+            trap_Cvar_SetValue( "r_ext_texture_filter_anisotropic", qfalse );
+        
+        trap_Cvar_SetValue( "com_hunkmegs", 128 );
+        
+        
 	if ( s_graphicsoptions.geometry.curvalue == 2 )
 	{
 		trap_Cvar_SetValue( "r_lodBias", 0 );
@@ -640,7 +680,10 @@ static void GraphicsOptions_Event( void* ptr, int event ) {
 		s_graphicsoptions.texturebits.curvalue = ivo->texturebits;
 		s_graphicsoptions.geometry.curvalue    = ivo->geometry;
 		s_graphicsoptions.filter.curvalue      = ivo->filter;
+                s_graphicsoptions.aniso.curvalue       = ivo->aniso;
 		s_graphicsoptions.fs.curvalue          = ivo->fullscreen;
+                s_graphicsoptions.flares.curvalue      = ivo->flares;
+                s_graphicsoptions.bloom.curvalue      = ivo->bloom;
 		break;
 
 	case ID_DRIVERINFO:
@@ -737,6 +780,11 @@ static void GraphicsOptions_SetMenuItems( void )
 	}
 	s_graphicsoptions.fs.curvalue = trap_Cvar_VariableValue("r_fullscreen");
 	s_graphicsoptions.allow_extensions.curvalue = trap_Cvar_VariableValue("r_allowExtensions");
+        s_graphicsoptions.flares.curvalue = trap_Cvar_VariableValue("r_flares");
+        s_graphicsoptions.bloom.curvalue = trap_Cvar_VariableValue("r_bloom");
+        if(trap_Cvar_VariableValue("r_ext_texture_filter_anisotropic")) {
+            s_graphicsoptions.aniso.curvalue = trap_Cvar_VariableValue("r_ext_max_anisotropy")/2;
+        }
 	s_graphicsoptions.tq.curvalue = 3-trap_Cvar_VariableValue( "r_picmip");
 	if ( s_graphicsoptions.tq.curvalue < 0 )
 	{
@@ -846,8 +894,8 @@ void GraphicsOptions_MenuInit( void )
 
 	static const char *lighting_names[] =
 	{
-		"Lightmap",
-		"Vertex",
+		"Lightmap (Normal)",
+		"Vertex (Low)",
 		NULL
 	};
 
@@ -865,6 +913,17 @@ void GraphicsOptions_MenuInit( void )
 		"Trilinear",
 		NULL
 	};
+        
+        static const char *aniso_names[] =
+	{
+		"Off",
+		"2x",
+                "4x",
+                "6x",
+                "8x",
+		NULL
+	};
+        
 	static const char *quality_names[] =
 	{
 		"Low",
@@ -1041,6 +1100,24 @@ void GraphicsOptions_MenuInit( void )
 	s_graphicsoptions.lighting.generic.y	 = y;
 	s_graphicsoptions.lighting.itemnames     = lighting_names;
 	y += BIGCHAR_HEIGHT+2;
+        
+        // references/modifies "r_flares"
+	s_graphicsoptions.flares.generic.type     = MTYPE_SPINCONTROL;
+	s_graphicsoptions.flares.generic.name	  = "Flares:";
+	s_graphicsoptions.flares.generic.flags	  = QMF_PULSEIFFOCUS|QMF_SMALLFONT;
+	s_graphicsoptions.flares.generic.x	      = 400;
+	s_graphicsoptions.flares.generic.y	      = y;
+	s_graphicsoptions.flares.itemnames	      = enabled_names;
+	y += BIGCHAR_HEIGHT+2;
+        
+        // references/modifies "r_bloom"
+	s_graphicsoptions.bloom.generic.type     = MTYPE_SPINCONTROL;
+	s_graphicsoptions.bloom.generic.name	  = "Bloom:";
+	s_graphicsoptions.bloom.generic.flags	  = QMF_PULSEIFFOCUS|QMF_SMALLFONT;
+	s_graphicsoptions.bloom.generic.x	      = 400;
+	s_graphicsoptions.bloom.generic.y	      = y;
+	s_graphicsoptions.bloom.itemnames	      = enabled_names;
+	y += BIGCHAR_HEIGHT+2;
 
 	// references/modifies "r_lodBias" & "subdivisions"
 	s_graphicsoptions.geometry.generic.type  = MTYPE_SPINCONTROL;
@@ -1078,6 +1155,14 @@ void GraphicsOptions_MenuInit( void )
 	s_graphicsoptions.filter.generic.x	    = 400;
 	s_graphicsoptions.filter.generic.y	    = y;
 	s_graphicsoptions.filter.itemnames      = filter_names;
+	y += 2+BIGCHAR_HEIGHT;
+        
+        s_graphicsoptions.aniso.generic.type   = MTYPE_SPINCONTROL;
+	s_graphicsoptions.aniso.generic.name	= "Anisotropy:";
+	s_graphicsoptions.aniso.generic.flags	= QMF_PULSEIFFOCUS|QMF_SMALLFONT;
+	s_graphicsoptions.aniso.generic.x	    = 400;
+	s_graphicsoptions.aniso.generic.y	    = y;
+	s_graphicsoptions.aniso.itemnames      = aniso_names;
 	y += 2*BIGCHAR_HEIGHT;
 
 	s_graphicsoptions.driverinfo.generic.type     = MTYPE_PTEXT;
@@ -1128,10 +1213,13 @@ void GraphicsOptions_MenuInit( void )
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.colordepth );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.fs );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.lighting );
+        Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.flares );
+        Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.bloom );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.geometry );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.tq );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.texturebits );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.filter );
+        Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.aniso );
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.driverinfo );
 
 	Menu_AddItem( &s_graphicsoptions.menu, ( void * ) &s_graphicsoptions.back );
