@@ -3310,7 +3310,7 @@ void FS_Restart( int checksumFeed ) {
 			lastValidBase[0] = '\0';
 			lastValidGame[0] = '\0';
 			FS_Restart(checksumFeed);
-			Com_Error( ERR_DROP, "Invalid game folder\n" );
+			Com_Error( ERR_DROP, "PK3 mismatch, you might need to upgrade.   See www.openarena.ws for more information\n" );
 			return;
 		}
 		Com_Error( ERR_FATAL, "Couldn't load default.cfg" );
