@@ -19,7 +19,7 @@ along with Quake III Arena source code; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 ===========================================================================
 */
-//
+
 #ifndef __Q_PLATFORM_H
 #define __Q_PLATFORM_H
 
@@ -122,6 +122,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifdef __linux__
 
+#include <endian.h>
+
 #define OS_STRING "linux"
 #define ID_INLINE inline
 #define PATH_SEP '/'
@@ -166,13 +168,21 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #endif
 
-//=============================================================== FreeBSD ===
+//=================================================================== BSD ===
 
-#ifdef __FreeBSD__ // rb010123
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
 
+#include <sys/types.h>
 #include <machine/endian.h>
 
+#if defined(__FreeBSD__)
 #define OS_STRING "freebsd"
+#elif defined(__OpenBSD__)
+#define OS_STRING "openbsd"
+#elif defined(__NetBSD__)
+#define OS_STRING "netbsd"
+#endif
+
 #define ID_INLINE inline
 #define PATH_SEP '/'
 
@@ -192,32 +202,6 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #endif
 
-//================================================================ NetBSD ===
-
-// This is very much like the FreeBSD one and can probably be merged
-#ifdef __NetBSD__
-
-#include <machine/endian.h>
-
-#define OS_STRING "netbsd"
-#define ID_INLINE inline
-#define PATH_SEP '/'
-
-#ifdef __i386__
-#define ARCH_STRING "i386"
-// Netbsd has alot of platforms
-#endif
-
-#if BYTE_ORDER == BIG_ENDIAN
-#define Q3_BIG_ENDIAN
-#else
-#define Q3_LITTLE_ENDIAN
-#endif
-
-#define DLL_EXT ".so"
-
-#endif
-
 //================================================================= SUNOS ===
 
 #ifdef __sun
@@ -245,6 +229,22 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #endif
 
+//================================================================== IRIX ===
+
+#ifdef __sgi
+
+#define OS_STRING "irix"
+#define ID_INLINE __inline
+#define PATH_SEP '/'
+
+#define ARCH_STRING "mips"
+
+#define Q3_BIG_ENDIAN // SGI's MIPS are always big endian
+
+#define DLL_EXT ".so"
+
+#endif
+
 //================================================================== Q3VM ===
 
 #ifdef Q3_VM
