@@ -287,16 +287,6 @@ static void IN_ActivateMouse( void )
 
 	if( !mouseActive )
 	{
-		//Sago: Here I prevent the queu from being overflowed (unless I'm really )
-		SDL_EventState(SDL_MOUSEMOTION,SDL_IGNORE);
-		SDL_EventState(SDL_ACTIVEEVENT,SDL_IGNORE);
-		SDL_EventState(SDL_JOYAXISMOTION,SDL_IGNORE);
-		SDL_EventState(SDL_JOYBALLMOTION,SDL_IGNORE);
-		SDL_EventState(SDL_JOYHATMOTION,SDL_IGNORE);
-		SDL_EventState(SDL_JOYBUTTONDOWN,SDL_IGNORE);
-		SDL_EventState(SDL_JOYBUTTONUP,SDL_IGNORE);
-		SDL_EventState(SDL_SYSWMEVENT,SDL_IGNORE);
-
 		SDL_WM_GrabInput( SDL_GRAB_ON );
 		SDL_ShowCursor( 0 );
 
@@ -660,7 +650,8 @@ static void IN_ProcessEvents( void )
 {
 	SDL_Event e;
 	const char *p = NULL;
-	int x,y,key = 0;
+	int key = 0;
+	int mx = 0, my = 0;
 
 	if( !SDL_WasInit( SDL_INIT_VIDEO ) )
 			return;
@@ -699,11 +690,14 @@ static void IN_ProcessEvents( void )
 				Com_QueueEvent( 0, SE_KEY, key, qfalse, 0, NULL );
 				break;
 
-			/*case SDL_MOUSEMOTION:
+			case SDL_MOUSEMOTION:
 				if (mouseActive)
-					Com_QueueEvent( 0, SE_MOUSE, e.motion.xrel, e.motion.yrel, 0, NULL );
+				{
+					mx += e.motion.xrel;
+					my += e.motion.yrel;
+				}
 				break;
-*/
+
 			case SDL_MOUSEBUTTONDOWN:
 			case SDL_MOUSEBUTTONUP:
 				{
@@ -733,11 +727,8 @@ static void IN_ProcessEvents( void )
 		}
 	}
 
-//Sago: Added this little thing instead of reading the events:
-	SDL_GetRelativeMouseState(&x, &y);
-	if( (x!=0 || y!=0 ) &&  mouseActive)
-		Com_QueueEvent( 0, SE_MOUSE, x, y, 0, NULL );
-		
+	if(mx || my)
+		Com_QueueEvent( 0, SE_MOUSE, mx, my, 0, NULL );
 }
 
 /*
