@@ -227,10 +227,13 @@ void SV_MasterHeartbeat( void ) {
 	static netadr_t	adr[MAX_MASTER_SERVERS];
 	int			i;
 
+#ifndef DEDICATED
+//Sago: to prevent a nasty bug intruduced by protocols this should not be checked in the dedicated binary
 	// "dedicated 1" is for lan play, "dedicated 2" is for inet public play
 	if ( !com_dedicated || com_dedicated->integer != 2 ) {
 		return;		// only dedicated servers send heartbeats
 	}
+#endif
 
 	// if not time yet, don't send anything
 	if ( svs.time < svs.nextHeartbeatTime ) {
